More collecting of globals.
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index 31994c20c36da0bb0759ffe1748ef439f91033f6..2d89757936d286855fbb4f70eeddfe86f270fce3 100644 (file)
--- a/score.c
+++ b/score.c
@@ -17,7 +17,7 @@ void score(long MODE) {
  *  Each treasure > chest    16                   224
  *  Surviving             (MAX-NUM)*10             30
  *  Not quitting              4                     4
- *  Reaching "CLOSNG"        25                    25
+ *  Reaching "game.closng"        25                    25
  *  "Closed": Quit/Killed    10
  *            Klutzed        25
  *            Wrong way      30
@@ -40,36 +40,36 @@ void score(long MODE) {
        if(I == CHEST)K=14;
        if(I > CHEST)K=16;
        if(PROP[I] >= 0)SCORE=SCORE+2;
-       if(PLACE[I] == 3 && PROP[I] == 0)SCORE=SCORE+K-2;
+       if(game.place[I] == 3 && PROP[I] == 0)SCORE=SCORE+K-2;
        MXSCOR=MXSCOR+K;
 L20010: /*etc*/ ;
        } /* end loop */
 
/*  Now look at how he finished and how far he got.  MAXDIE and NUMDIE tell us
*  how well he survived.  DFLAG will
*  tell us if he ever got suitably deep into the cave.  CLOSNG still indicates
  *  whether he reached the endgame.  And if he got as far as "cave closed"
*  (indicated by "CLOSED"), then bonus is zero for mundane exits or 133, 134,
  *  135 if he blew it (so to speak). */
 
-       SCORE=SCORE+(MAXDIE-NUMDIE)*10;
+       SCORE=SCORE+(MAXDIE-game.numdie)*10;
        MXSCOR=MXSCOR+MAXDIE*10;
        if(MODE == 0)SCORE=SCORE+4;
        MXSCOR=MXSCOR+4;
-       if(DFLAG != 0)SCORE=SCORE+25;
+       if(game.dflag != 0)SCORE=SCORE+25;
        MXSCOR=MXSCOR+25;
-       if(CLOSNG)SCORE=SCORE+25;
+       if(game.closng)SCORE=SCORE+25;
        MXSCOR=MXSCOR+25;
-       if(!CLOSED) goto L20020;
-       if(BONUS == 0)SCORE=SCORE+10;
-       if(BONUS == 135)SCORE=SCORE+25;
-       if(BONUS == 134)SCORE=SCORE+30;
-       if(BONUS == 133)SCORE=SCORE+45;
+       if(!game.closed) goto L20020;
+       if(game.bonus == 0)SCORE=SCORE+10;
+       if(game.bonus == 135)SCORE=SCORE+25;
+       if(game.bonus == 134)SCORE=SCORE+30;
+       if(game.bonus == 133)SCORE=SCORE+45;
 L20020: MXSCOR=MXSCOR+45;
 
 /*  Did he come to Witt's End as he should? */
 
-       if(PLACE[MAGZIN] == 108)SCORE=SCORE+1;
+       if(game.place[MAGZIN] == 108)SCORE=SCORE+1;
        MXSCOR=MXSCOR+1;
 
 /*  Round it off. */
@@ -80,11 +80,11 @@ L20020: MXSCOR=MXSCOR+45;
 /*  Deduct for hints/turns/saves.  Hints < 4 are special; see database desc. */
 
        for (I=1; I<=HNTMAX; I++) {
-       if(HINTED[I])SCORE=SCORE-HINTS[I][2];
+       if(game.hinted[I])SCORE=SCORE-HINTS[I][2];
        } /* end loop */
-       if(NOVICE)SCORE=SCORE-5;
-       if(CLSHNT)SCORE=SCORE-10;
-       SCORE=SCORE-TRNLUZ-SAVED;
+       if(game.novice)SCORE=SCORE-5;
+       if(game.clshnt)SCORE=SCORE-10;
+       SCORE=SCORE-game.trnluz-game.saved;
 
 /*  Return to score command if that's where we came from. */
 
@@ -92,10 +92,10 @@ L20020: MXSCOR=MXSCOR+45;
 
 /*  that should be good enough.  Let's tell him all about it. */
 
-       if(SCORE+TRNLUZ+1 >= MXSCOR && TRNLUZ != 0)RSPEAK(242);
-       if(SCORE+SAVED+1 >= MXSCOR && SAVED != 0)RSPEAK(143);
+       if(SCORE+game.trnluz+1 >= MXSCOR && game.trnluz != 0)RSPEAK(242);
+       if(SCORE+game.saved+1 >= MXSCOR && game.saved != 0)RSPEAK(143);
        SETPRM(1,SCORE,MXSCOR);
-       SETPRM(3,TURNS,TURNS);
+       SETPRM(3,game.turns,game.turns);
        RSPEAK(262);
        for (I=1; I<=CLSSES; I++) {
        if(CVAL[I] >= SCORE) goto L20210;
@@ -40,36 +40,36 @@ void score(long MODE) {
        } /* end loop */
 
-/*  Now look at how he finished and how far he got.  MAXDIE and NUMDIE tell us
- *  how well he survived.  DFLAG will
- *  tell us if he ever got suitably deep into the cave.  CLOSNG still indicates
+/*  Now look at how he finished and how far he got.  MAXDIE and game.numdie tell us
+ *  how well he survived.  game.dflag will
+ *  tell us if he ever got suitably deep into the cave.  game.closng still indicates
  *  whether he reached the endgame.  And if he got as far as "cave closed"
@@ -40,36 +40,36 @@ void score(long MODE) {
  *  whether he reached the endgame.  And if he got as far as "cave closed"
- *  (indicated by "CLOSED"), then bonus is zero for mundane exits or 133, 134,
+ *  (indicated by "game.closed"), then bonus is zero for mundane exits or 133, 134,
  *  135 if he blew it (so to speak). */
 